@@ -1,25 +1,22 @@
-from collections import namedtuple
-from copy import deepcopy
 import re
-import sys
 import textwrap
 import warnings
+from collections import namedtuple
+from copy import deepcopy
 
 import jinja2
+import pytest
+from pytest import warns as assert_warns
 
-from numpydoc.numpydoc import update_config
-from numpydoc.xref import DEFAULT_LINKS
-from numpydoc.docscrape import NumpyDocString, FunctionDoc, ClassDoc, ParseError
+from numpydoc.docscrape import ClassDoc, FunctionDoc, NumpyDocString
 from numpydoc.docscrape_sphinx import (
-    SphinxDocString,
     SphinxClassDoc,
+    SphinxDocString,
     SphinxFunctionDoc,
     get_doc_object,
 )
-import pytest
-from pytest import raises as assert_raises
-from pytest import warns as assert_warns
-
+from numpydoc.numpydoc import update_config
+from numpydoc.xref import DEFAULT_LINKS
 
 doc_txt = """\
   numpy.multivariate_normal(mean, cov, shape=None, spam=None)
@@ -280,7 +277,9 @@ b : int
     The number of bananas.
 
 """
-    assert_raises(ValueError, NumpyDocString, doc_text)
+    doc = NumpyDocString(doc_text)
+    assert len(doc["Returns"]) == 1
+    assert len(doc["Yields"]) == 2
 
 
 def test_section_twice():
@@ -315,11 +314,9 @@ That should break...
 
         def spam(self, a, b):
             """Spam\n\nSpam spam."""
-            pass
 
         def ham(self, c, d):
             """Cheese\n\nNo cheese."""
-            pass
 
     def dummy_func(arg):
         """
@@ -852,11 +849,11 @@ def test_see_also(prefix):
 
             if func == "func_h":
                 assert role == "meth"
-            elif func == "baz.obj_q" or func == "~baz.obj_r":
+            elif func in ("baz.obj_q", "~baz.obj_r"):
                 assert role == "obj"
             elif func == "class_j":
                 assert role == "class"
-            elif func in ["func_h1", "func_h2"]:
+            elif func in ("func_h1", "func_h2"):
                 assert role == "meth"
             else:
                 assert role is None, str([func, role])
@@ -867,7 +864,7 @@ def test_see_also(prefix):
                 assert desc == ["some other func over", "multiple lines"]
             elif func == "class_j":
                 assert desc == ["fubar", "foobar"]
-            elif func in ["func_f2", "func_g2", "func_h2", "func_j2"]:
+            elif func in ("func_f2", "func_g2", "func_h2", "func_j2"):
                 assert desc == ["description of multiple"], str(
                     [desc, ["description of multiple"]]
                 )
@@ -896,8 +893,6 @@ def test_see_also_print():
         func_d
         """
 
-        pass
-
     s = str(FunctionDoc(Dummy, role="func"))
     assert ":func:`func_a`, :func:`func_b`" in s
     assert "    some relationship" in s
@@ -940,8 +935,6 @@ This should be ignored and warned about
         This class has a nope section.
         """
 
-        pass
-
     with pytest.warns(UserWarning, match="Unknown section Mope") as record:
         NumpyDocString(doc_text)
     assert len(record) == 1
@@ -1084,11 +1077,9 @@ def test_class_members():
 
         def spam(self, a, b):
             """Spam\n\nSpam spam."""
-            pass
 
         def ham(self, c, d):
             """Cheese\n\nNo cheese."""
-            pass
 
         @property
         def spammity(self):
@@ -1098,8 +1089,6 @@ def test_class_members():
         class Ignorable:
             """local class, to be ignored"""
 
-            pass
-
     for cls in (ClassDoc, SphinxClassDoc):
         doc = cls(Dummy, config=dict(show_class_members=False))
         assert "Methods" not in str(doc), (cls, str(doc))
@@ -1127,11 +1116,9 @@ def test_class_members():
 
         def ham(self, c, d):
             """Cheese\n\nNo cheese.\nOverloaded Dummy.ham"""
-            pass
 
         def bar(self, a, b):
             """Bar\n\nNo bar"""
-            pass
 
     for cls in (ClassDoc, SphinxClassDoc):
         doc = cls(
@@ -1216,6 +1203,17 @@ class_doc_txt = """
     b
     c
 
+    Other Parameters
+    ----------------
+
+    another parameter : str
+        This parameter is less important.
+
+    Notes
+    -----
+
+    Some notes about the class.
+
     Examples
     --------
     For usage examples, see `ode`.
@@ -1236,10 +1234,6 @@ def test_class_members_doc():
     jac : callable ``jac(t, y, *jac_args)``
         Bbb.
 
-    Examples
-    --------
-    For usage examples, see `ode`.
-
     Attributes
     ----------
     t : float
@@ -1264,6 +1258,19 @@ def test_class_members_doc():
     b
     c
 
+    Other Parameters
+    ----------------
+    another parameter : str
+        This parameter is less important.
+
+    Notes
+    -----
+    Some notes about the class.
+
+    Examples
+    --------
+    For usage examples, see `ode`.
+
     """,
     )
 
@@ -1273,7 +1280,7 @@ def test_class_members_doc_sphinx():
         @property
         def an_attribute(self):
             """Test attribute"""
-            return None
+            return
 
         @property
         def no_docstring(self):
@@ -1287,12 +1294,12 @@ def test_class_members_doc_sphinx():
         def multiline_sentence(self):
             """This is a
             sentence. It spans multiple lines."""
-            return None
+            return
 
         @property
         def midword_period(self):
             """The sentence for numpy.org."""
-            return None
+            return
 
         @property
         def no_period(self):
@@ -1301,7 +1308,7 @@ def test_class_members_doc_sphinx():
 
             Apparently.
             """
-            return None
+            return
 
     doc = SphinxClassDoc(Foo, class_doc_txt)
     line_by_line_compare(
@@ -1317,10 +1324,6 @@ def test_class_members_doc_sphinx():
         **jac** : callable ``jac(t, y, *jac_args)``
             Bbb.
 
-    .. rubric:: Examples
-
-    For usage examples, see `ode`.
-
     :Attributes:
 
         **t** : float
@@ -1358,6 +1361,19 @@ def test_class_members_doc_sphinx():
     **c**
     =====  ==========
 
+    :Other Parameters:
+
+        **another parameter** : str
+            This parameter is less important.
+
+    .. rubric:: Notes
+
+    Some notes about the class.
+
+    .. rubric:: Examples
+
+    For usage examples, see `ode`.
+
     """,
     )
 
@@ -1377,7 +1393,7 @@ def test_class_attributes_as_member_list():
         @property
         def an_attribute(self):
             """Test attribute"""
-            return None
+            return
 
     attr_doc = """:Attributes:
 
@@ -1443,7 +1459,6 @@ def test_nonstandard_property():
             obj._set_axis(self.axis, value)
 
     class Dummy:
-
         attr = SpecialProperty(doc="test attribute")
 
     doc = get_doc_object(Dummy)
@@ -1578,6 +1593,7 @@ def test_xref():
             # numpydoc.update_config fails if this config option not present
             self.numpydoc_validation_checks = set()
             self.numpydoc_validation_exclude = set()
+            self.numpydoc_validation_overrides = dict()
 
     xref_aliases_complete = deepcopy(DEFAULT_LINKS)
     for key in xref_aliases:
@@ -1625,9 +1641,6 @@ def test__error_location_no_name_attr():
         nds._error_location(msg=msg)
 
 
-@pytest.mark.skipif(
-    sys.version_info < (3, 8), reason="cached_property was added in 3.8"
-)
 def test_class_docstring_cached_property():
     """Ensure that properties marked with the `cached_property` decorator
     are listed in the Methods section. See gh-432."""
@@ -1645,6 +1658,63 @@ def test_class_docstring_cached_property():
     assert class_docstring["Attributes"][0].name == "val"
 
 
+def test_namedtuple_no_duplicate_attributes():
+    """
+    Ensure that attributes of namedtuples are not duplicated in the docstring.
+
+    See gh-257
+    """
+    from collections import namedtuple
+
+    foo = namedtuple("Foo", ("bar", "baz"))
+
+    # Create the SphinxClassDoc object via get_doc_object
+    sds = get_doc_object(foo)
+    assert sds["Attributes"] == []
+
+
+def test_namedtuple_class_docstring():
+    """Ensure that class docstring is preserved when inheriting from namedtuple.
+
+    See gh-257
+    """
+    from collections import namedtuple
+
+    foo = namedtuple("Foo", ("bar", "baz"))
+
+    class MyFoo(foo):
+        """MyFoo's class docstring"""
+
+    # Create the SphinxClassDoc object via get_doc_object
+    sds = get_doc_object(MyFoo)
+    assert sds["Summary"] == ["MyFoo's class docstring"]
+
+    # Example dataclass where constructor params are documented explicit.
+    # Parameter names/descriptions should be included in the docstring, but
+    # should not result in a duplicated `Attributes` section
+    class MyFooWithParams(foo):
+        """
+        MyFoo's class docstring
+
+        Parameters
+        ----------
+        bar : str
+           The bar attribute
+        baz : str
+           The baz attribute
+        """
+
+        bar: str
+        baz: str
+
+    sds = get_doc_object(MyFooWithParams)
+    assert "MyFoo's class docstring" in sds["Summary"]
+    assert len(sds["Attributes"]) == 0
+    assert len(sds["Parameters"]) == 2
+    assert sds["Parameters"][0].desc[0] == "The bar attribute"
+    assert sds["Parameters"][1].desc[0] == "The baz attribute"
+
+
 if __name__ == "__main__":
     import pytest
 
