@@ -4,7 +4,7 @@ import sys
 path = os.path.dirname(__file__)
 if path not in sys.path:
     sys.path.insert(0, path)
-import numpydoc_test_module  # noqa
+import numpydoc_test_module
 
 extensions = [
     "sphinx.ext.autodoc",
@@ -15,7 +15,6 @@ project = "numpydoc_test_module"
 autosummary_generate = True
 autodoc_default_options = {"inherited-members": None}
 source_suffix = ".rst"
-master_doc = "index"  # NOTE: will be changed to `root_doc` in sphinx 4
 exclude_patterns = ["_build"]
 intersphinx_mapping = {
     "python": ("https://docs.python.org/3", None),
